==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/SkypeChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.SkypeChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Microsoft Teams channel.
 * @property callingWebHook Calling web hook for Skype channel
 * @property enableCalling Enable calling for Skype channel
 * @property enableGroups Enable groups for Skype channel
 * @property enableMediaCards Enable media cards for Skype channel
 * @property enableMessaging Enable messaging for Skype channel
 * @property enableScreenSharing Enable screen sharing for Skype channel
 * @property enableVideo Enable video for Skype channel
 * @property groupsMode Group mode for Skype channel
 * @property incomingCallRoute Incoming call route for Skype channel
 * @property isEnabled Whether this channel is enabled for the bot
 */
public data class SkypeChannelPropertiesArgs(
    public val callingWebHook: Output<String>? = null,
    public val enableCalling: Output<Boolean>? = null,
    public val enableGroups: Output<Boolean>? = null,
    public val enableMediaCards: Output<Boolean>? = null,
    public val enableMessaging: Output<Boolean>? = null,
    public val enableScreenSharing: Output<Boolean>? = null,
    public val enableVideo: Output<Boolean>? = null,
    public val groupsMode: Output<String>? = null,
    public val incomingCallRoute: Output<String>? = null,
    public val isEnabled: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.SkypeChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.SkypeChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.SkypeChannelPropertiesArgs.builder()
            .callingWebHook(callingWebHook?.applyValue({ args0 -> args0 }))
            .enableCalling(enableCalling?.applyValue({ args0 -> args0 }))
            .enableGroups(enableGroups?.applyValue({ args0 -> args0 }))
            .enableMediaCards(enableMediaCards?.applyValue({ args0 -> args0 }))
            .enableMessaging(enableMessaging?.applyValue({ args0 -> args0 }))
            .enableScreenSharing(enableScreenSharing?.applyValue({ args0 -> args0 }))
            .enableVideo(enableVideo?.applyValue({ args0 -> args0 }))
            .groupsMode(groupsMode?.applyValue({ args0 -> args0 }))
            .incomingCallRoute(incomingCallRoute?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkypeChannelPropertiesArgs].
 */
@PulumiTagMarker
public class SkypeChannelPropertiesArgsBuilder internal constructor() {
    private var callingWebHook: Output<String>? = null

    private var enableCalling: Output<Boolean>? = null

    private var enableGroups: Output<Boolean>? = null

    private var enableMediaCards: Output<Boolean>? = null

    private var enableMessaging: Output<Boolean>? = null

    private var enableScreenSharing: Output<Boolean>? = null

    private var enableVideo: Output<Boolean>? = null

    private var groupsMode: Output<String>? = null

    private var incomingCallRoute: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    /**
     * @param value Calling web hook for Skype channel
     */
    @JvmName("oufgvljaeiacijgo")
    public suspend fun callingWebHook(`value`: Output<String>) {
        this.callingWebHook = value
    }

    /**
     * @param value Enable calling for Skype channel
     */
    @JvmName("aoeibjxroobvhiqo")
    public suspend fun enableCalling(`value`: Output<Boolean>) {
        this.enableCalling = value
    }

    /**
     * @param value Enable groups for Skype channel
     */
    @JvmName("tvhaolfgcmkgbjrt")
    public suspend fun enableGroups(`value`: Output<Boolean>) {
        this.enableGroups = value
    }

    /**
     * @param value Enable media cards for Skype channel
     */
    @JvmName("hhdxoakpksnyrtxn")
    public suspend fun enableMediaCards(`value`: Output<Boolean>) {
        this.enableMediaCards = value
    }

    /**
     * @param value Enable messaging for Skype channel
     */
    @JvmName("ypghnqfmatbdeaxr")
    public suspend fun enableMessaging(`value`: Output<Boolean>) {
        this.enableMessaging = value
    }

    /**
     * @param value Enable screen sharing for Skype channel
     */
    @JvmName("gfpgleonivpjqqen")
    public suspend fun enableScreenSharing(`value`: Output<Boolean>) {
        this.enableScreenSharing = value
    }

    /**
     * @param value Enable video for Skype channel
     */
    @JvmName("whbmebiftolnuhrs")
    public suspend fun enableVideo(`value`: Output<Boolean>) {
        this.enableVideo = value
    }

    /**
     * @param value Group mode for Skype channel
     */
    @JvmName("dxtafsowqiqnwtvk")
    public suspend fun groupsMode(`value`: Output<String>) {
        this.groupsMode = value
    }

    /**
     * @param value Incoming call route for Skype channel
     */
    @JvmName("vrkdrmliqhtwlbpo")
    public suspend fun incomingCallRoute(`value`: Output<String>) {
        this.incomingCallRoute = value
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("mmccglssxxakeiow")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Calling web hook for Skype channel
     */
    @JvmName("wjboetoxwjbrqjcb")
    public suspend fun callingWebHook(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.callingWebHook = mapped
    }

    /**
     * @param value Enable calling for Skype channel
     */
    @JvmName("rjaeasodaasxblyt")
    public suspend fun enableCalling(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableCalling = mapped
    }

    /**
     * @param value Enable groups for Skype channel
     */
    @JvmName("yhraplbkbsdhtjxq")
    public suspend fun enableGroups(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableGroups = mapped
    }

    /**
     * @param value Enable media cards for Skype channel
     */
    @JvmName("bshdlwlskffnkgkr")
    public suspend fun enableMediaCards(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableMediaCards = mapped
    }

    /**
     * @param value Enable messaging for Skype channel
     */
    @JvmName("jwwqddluwytuycab")
    public suspend fun enableMessaging(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableMessaging = mapped
    }

    /**
     * @param value Enable screen sharing for Skype channel
     */
    @JvmName("fnhvdyoaqrlgxyht")
    public suspend fun enableScreenSharing(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableScreenSharing = mapped
    }

    /**
     * @param value Enable video for Skype channel
     */
    @JvmName("kcbvousfjebaiepm")
    public suspend fun enableVideo(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableVideo = mapped
    }

    /**
     * @param value Group mode for Skype channel
     */
    @JvmName("obqngifputmrrexi")
    public suspend fun groupsMode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupsMode = mapped
    }

    /**
     * @param value Incoming call route for Skype channel
     */
    @JvmName("ncwhdbgihkxfmemh")
    public suspend fun incomingCallRoute(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incomingCallRoute = mapped
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("wwvatdlehqdjwehl")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    internal fun build(): SkypeChannelPropertiesArgs = SkypeChannelPropertiesArgs(
        callingWebHook = callingWebHook,
        enableCalling = enableCalling,
        enableGroups = enableGroups,
        enableMediaCards = enableMediaCards,
        enableMessaging = enableMessaging,
        enableScreenSharing = enableScreenSharing,
        enableVideo = enableVideo,
        groupsMode = groupsMode,
        incomingCallRoute = incomingCallRoute,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/SkypeChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.SkypeChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Microsoft Teams channel.
 * @property callingWebHook Calling web hook for Skype channel
 * @property enableCalling Enable calling for Skype channel
 * @property enableGroups Enable groups for Skype channel
 * @property enableMediaCards Enable media cards for Skype channel
 * @property enableMessaging Enable messaging for Skype channel
 * @property enableScreenSharing Enable screen sharing for Skype channel
 * @property enableVideo Enable video for Skype channel
 * @property groupsMode Group mode for Skype channel
 * @property incomingCallRoute Incoming call route for Skype channel
 * @property isEnabled Whether this channel is enabled for the bot
 */
public data class SkypeChannelPropertiesArgs(
    public val callingWebHook: Output<String>? = null,
    public val enableCalling: Output<Boolean>? = null,
    public val enableGroups: Output<Boolean>? = null,
    public val enableMediaCards: Output<Boolean>? = null,
    public val enableMessaging: Output<Boolean>? = null,
    public val enableScreenSharing: Output<Boolean>? = null,
    public val enableVideo: Output<Boolean>? = null,
    public val groupsMode: Output<String>? = null,
    public val incomingCallRoute: Output<String>? = null,
    public val isEnabled: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.SkypeChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.SkypeChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.SkypeChannelPropertiesArgs.builder()
            .callingWebHook(callingWebHook?.applyValue({ args0 -> args0 }))
            .enableCalling(enableCalling?.applyValue({ args0 -> args0 }))
            .enableGroups(enableGroups?.applyValue({ args0 -> args0 }))
            .enableMediaCards(enableMediaCards?.applyValue({ args0 -> args0 }))
            .enableMessaging(enableMessaging?.applyValue({ args0 -> args0 }))
            .enableScreenSharing(enableScreenSharing?.applyValue({ args0 -> args0 }))
            .enableVideo(enableVideo?.applyValue({ args0 -> args0 }))
            .groupsMode(groupsMode?.applyValue({ args0 -> args0 }))
            .incomingCallRoute(incomingCallRoute?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkypeChannelPropertiesArgs].
 */
@PulumiTagMarker
public class SkypeChannelPropertiesArgsBuilder internal constructor() {
    private var callingWebHook: Output<String>? = null

    private var enableCalling: Output<Boolean>? = null

    private var enableGroups: Output<Boolean>? = null

    private var enableMediaCards: Output<Boolean>? = null

    private var enableMessaging: Output<Boolean>? = null

    private var enableScreenSharing: Output<Boolean>? = null

    private var enableVideo: Output<Boolean>? = null

    private var groupsMode: Output<String>? = null

    private var incomingCallRoute: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    /**
     * @param value Calling web hook for Skype channel
     */
    @JvmName("xpxgqxifrnwclbwv")
    public suspend fun callingWebHook(`value`: Output<String>) {
        this.callingWebHook = value
    }

    /**
     * @param value Enable calling for Skype channel
     */
    @JvmName("ekehddoshpyynbgp")
    public suspend fun enableCalling(`value`: Output<Boolean>) {
        this.enableCalling = value
    }

    /**
     * @param value Enable groups for Skype channel
     */
    @JvmName("mbjmgihqbrxtilgl")
    public suspend fun enableGroups(`value`: Output<Boolean>) {
        this.enableGroups = value
    }

    /**
     * @param value Enable media cards for Skype channel
     */
    @JvmName("tardopuipgvbuhsi")
    public suspend fun enableMediaCards(`value`: Output<Boolean>) {
        this.enableMediaCards = value
    }

    /**
     * @param value Enable messaging for Skype channel
     */
    @JvmName("cgsrdrpeuxyckmou")
    public suspend fun enableMessaging(`value`: Output<Boolean>) {
        this.enableMessaging = value
    }

    /**
     * @param value Enable screen sharing for Skype channel
     */
    @JvmName("oyqikrsrdjelmjgg")
    public suspend fun enableScreenSharing(`value`: Output<Boolean>) {
        this.enableScreenSharing = value
    }

    /**
     * @param value Enable video for Skype channel
     */
    @JvmName("fbvgefjnfrbopmsb")
    public suspend fun enableVideo(`value`: Output<Boolean>) {
        this.enableVideo = value
    }

    /**
     * @param value Group mode for Skype channel
     */
    @JvmName("hnjsqfakxfuwwlhd")
    public suspend fun groupsMode(`value`: Output<String>) {
        this.groupsMode = value
    }

    /**
     * @param value Incoming call route for Skype channel
     */
    @JvmName("fetgfnegmfkiixbe")
    public suspend fun incomingCallRoute(`value`: Output<String>) {
        this.incomingCallRoute = value
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("gsodulkgjcyjoiji")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Calling web hook for Skype channel
     */
    @JvmName("snefjuaqqdigembj")
    public suspend fun callingWebHook(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.callingWebHook = mapped
    }

    /**
     * @param value Enable calling for Skype channel
     */
    @JvmName("xambjlftewxnybwa")
    public suspend fun enableCalling(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableCalling = mapped
    }

    /**
     * @param value Enable groups for Skype channel
     */
    @JvmName("yaqquqvsbcdlyctr")
    public suspend fun enableGroups(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableGroups = mapped
    }

    /**
     * @param value Enable media cards for Skype channel
     */
    @JvmName("smteddijylqhwbsa")
    public suspend fun enableMediaCards(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableMediaCards = mapped
    }

    /**
     * @param value Enable messaging for Skype channel
     */
    @JvmName("lcdeubsavopracgn")
    public suspend fun enableMessaging(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableMessaging = mapped
    }

    /**
     * @param value Enable screen sharing for Skype channel
     */
    @JvmName("hmiblprborbsdanu")
    public suspend fun enableScreenSharing(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableScreenSharing = mapped
    }

    /**
     * @param value Enable video for Skype channel
     */
    @JvmName("qwihivoqwrvwvdxt")
    public suspend fun enableVideo(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableVideo = mapped
    }

    /**
     * @param value Group mode for Skype channel
     */
    @JvmName("sbdngmaleykmxtqt")
    public suspend fun groupsMode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupsMode = mapped
    }

    /**
     * @param value Incoming call route for Skype channel
     */
    @JvmName("dtlxhkupwxanotgy")
    public suspend fun incomingCallRoute(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incomingCallRoute = mapped
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("oatoyagnkirqmsyx")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    internal fun build(): SkypeChannelPropertiesArgs = SkypeChannelPropertiesArgs(
        callingWebHook = callingWebHook,
        enableCalling = enableCalling,
        enableGroups = enableGroups,
        enableMediaCards = enableMediaCards,
        enableMessaging = enableMessaging,
        enableScreenSharing = enableScreenSharing,
        enableVideo = enableVideo,
        groupsMode = groupsMode,
        incomingCallRoute = incomingCallRoute,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
    )
}
